Attention is currently required from: pespin.
fixeria has posted comments on this change by pespin. ( https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38615?usp=email )
Change subject: statsd: Support f_statsd_snapshot() API when using VTY-triggered stats report
......................................................................
Patch Set 1: Code-Review+2
--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38615?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: I87d34e2f365d3b71ce328c08999be43d482326ad
Gerrit-Change-Number: 38615
Gerrit-PatchSet: 1
Gerrit-Owner: pespin <pespin(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: osmith <osmith(a)sysmocom.de>
Gerrit-Attention: pespin <pespin(a)sysmocom.de>
Gerrit-Comment-Date: Mon, 04 Nov 2024 15:50:45 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
osmith has submitted this change. ( https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38620?usp=email )
Change subject: testenv: fix 'container crashed' detection
......................................................................
testenv: fix 'container crashed' detection
* When the testsuite stopped and using podman, check if it stopped
because the container crashed and raise an exception.
* Even after 9eb5e696 ("testenv: make podman stop more robust") it
happens sometimes in jenkins that the container gets stopped on
purpose because the testsuite is done, but then the watchdog process
prints an error saying it crashed (without actually stopping testenv
at this point). Change the message to a debug message that just says
it stopped, this should not be an error.
Related: OS#6607
Change-Id: I3c116719cdc00a99e27e5237ba3d57d5258b0919
---
M _testenv/testenv/podman.py
M _testenv/testenv/testsuite.py
2 files changed, 3 insertions(+), 1 deletion(-)
Approvals:
Jenkins Builder: Verified
fixeria: Looks good to me, approved
pespin: Looks good to me, but someone else must approve
diff --git a/_testenv/testenv/podman.py b/_testenv/testenv/podman.py
index 719afcb..dc1b333 100644
--- a/_testenv/testenv/podman.py
+++ b/_testenv/testenv/podman.py
@@ -179,7 +179,7 @@
time.sleep(5)
p = subprocess.run(["podman", "exec", container_name, "touch", "/tmp/watchdog"])
if p.returncode:
- logging.error("podman container crashed!")
+ logging.debug("feed_watchdog_loop: podman container has stopped")
return
except KeyboardInterrupt:
pass
diff --git a/_testenv/testenv/testsuite.py b/_testenv/testenv/testsuite.py
index 601f339..3bc8d9d 100644
--- a/_testenv/testenv/testsuite.py
+++ b/_testenv/testenv/testsuite.py
@@ -195,6 +195,8 @@
time.sleep(1)
if not is_running(testsuite_proc.pid):
+ if testenv.args.podman and not testenv.podman.is_running():
+ raise testenv.NoTraceException("podman container crashed!")
logging.debug("Testsuite is done")
stop()
break
--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38620?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: merged
Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: I3c116719cdc00a99e27e5237ba3d57d5258b0919
Gerrit-Change-Number: 38620
Gerrit-PatchSet: 1
Gerrit-Owner: osmith <osmith(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: osmith <osmith(a)sysmocom.de>
Gerrit-Reviewer: pespin <pespin(a)sysmocom.de>
osmith has submitted this change. ( https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38621?usp=email )
Change subject: testenv: podman-main: set watchdog timer to 60s
......................................................................
testenv: podman-main: set watchdog timer to 60s
Increase the timer from 10s to 60s, as with 10s I see jobs failing with:
ERROR: /tmp/watchdog was not created, exiting
In theory 10s should already be enough, my guess is that if a jenkins
node is currently under a lot of load then the feed command may take
several seconds and so we hit the previous timer. Even if this is not
the cause, I think it is good to rule it out.
Exiting after 60s if the jenkins job was (manually / with connection
loss) aborted is still relatively quick.
Related: OS#6607
Change-Id: Ide7a9d5bc395106cdaa47cec3aa746a978674c9e
---
M _testenv/data/scripts/testenv-podman-main.sh
1 file changed, 3 insertions(+), 3 deletions(-)
Approvals:
pespin: Looks good to me, but someone else must approve
Jenkins Builder: Verified
fixeria: Looks good to me, approved
diff --git a/_testenv/data/scripts/testenv-podman-main.sh b/_testenv/data/scripts/testenv-podman-main.sh
index 4b080a6..7f1c16e 100755
--- a/_testenv/data/scripts/testenv-podman-main.sh
+++ b/_testenv/data/scripts/testenv-podman-main.sh
@@ -1,8 +1,8 @@
#!/bin/sh -e
# Simple watchdog script that exits if either:
# * testenv doesn't create /tmp/watchdog every 10s
# * 4 hours have passed
-# This ensures the podman container stops a few seconds after a jenkins job was
+# This ensures the podman container stops a soon after a jenkins job was
# aborted, or if a test is stuck in a loop for hours.
echo "Running testenv-podman-main.sh"
@@ -10,7 +10,7 @@
stop_time=$(($(date +%s) + 3600 * 4))
while [ $(date +%s) -lt $stop_time ]; do
- sleep 10
+ sleep 60
if ! [ -e /tmp/watchdog ]; then
echo "ERROR: /tmp/watchdog was not created, exiting"
@@ -1,8 +1,8 @@
#!/bin/sh -e
# Simple watchdog script that exits if either:
-# * testenv doesn't create /tmp/watchdog every 10s
+# * testenv doesn't create /tmp/watchdog every 60s
# * 4 hours have passed
--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38621?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: merged
Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Ide7a9d5bc395106cdaa47cec3aa746a978674c9e
Gerrit-Change-Number: 38621
Gerrit-PatchSet: 1
Gerrit-Owner: osmith <osmith(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: osmith <osmith(a)sysmocom.de>
Gerrit-Reviewer: pespin <pespin(a)sysmocom.de>
Attention is currently required from: osmith.
fixeria has posted comments on this change by osmith. ( https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38621?usp=email )
Change subject: testenv: podman-main: set watchdog timer to 60s
......................................................................
Patch Set 1: Code-Review+2
--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38621?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Ide7a9d5bc395106cdaa47cec3aa746a978674c9e
Gerrit-Change-Number: 38621
Gerrit-PatchSet: 1
Gerrit-Owner: osmith <osmith(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: pespin <pespin(a)sysmocom.de>
Gerrit-Attention: osmith <osmith(a)sysmocom.de>
Gerrit-Comment-Date: Mon, 04 Nov 2024 15:49:54 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Attention is currently required from: fixeria, laforge, pespin.
osmith has posted comments on this change by pespin. ( https://gerrit.osmocom.org/c/libosmo-pfcp/+/38612?usp=email )
Change subject: Make struct osmo_pfcp_cp_peer private
......................................................................
Patch Set 1: Code-Review+1
(1 comment)
Patchset:
PS1:
> I don't get what you mean here sorry. They are 2 separate patches for 2 separate topics. […]
ah got it now! maybe add some depends: or set it to draft until this is done?
This patch looks good to me, assuming osmo-hnbgw is fixed beforehand.
--
To view, visit https://gerrit.osmocom.org/c/libosmo-pfcp/+/38612?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: libosmo-pfcp
Gerrit-Branch: master
Gerrit-Change-Id: I7f79ce239cb3c57bae2cf5846edf71e1aa03fa95
Gerrit-Change-Number: 38612
Gerrit-PatchSet: 1
Gerrit-Owner: pespin <pespin(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-Reviewer: osmith <osmith(a)sysmocom.de>
Gerrit-Attention: laforge <laforge(a)osmocom.org>
Gerrit-Attention: pespin <pespin(a)sysmocom.de>
Gerrit-Attention: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Comment-Date: Mon, 04 Nov 2024 15:42:10 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: Yes
Comment-In-Reply-To: osmith <osmith(a)sysmocom.de>
Comment-In-Reply-To: pespin <pespin(a)sysmocom.de>
Attention is currently required from: fixeria, laforge, osmith.
pespin has posted comments on this change by pespin. ( https://gerrit.osmocom.org/c/libosmo-pfcp/+/38612?usp=email )
Change subject: Make struct osmo_pfcp_cp_peer private
......................................................................
Patch Set 1:
(1 comment)
Patchset:
PS1:
> Is there more breakage? I thought there is only https://gerrit.osmocom. […]
I don't get what you mean here sorry. They are 2 separate patches for 2 separate topics.
38613 you mention above is an orthogonal patch which adds an API I need to set the assoc_cb field.
This patch is about making all fields of struct private, but osmo-hnbgw is already using some other field in the struct directly, so we first need to fix osmo-hnbgw.
--
To view, visit https://gerrit.osmocom.org/c/libosmo-pfcp/+/38612?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: libosmo-pfcp
Gerrit-Branch: master
Gerrit-Change-Id: I7f79ce239cb3c57bae2cf5846edf71e1aa03fa95
Gerrit-Change-Number: 38612
Gerrit-PatchSet: 1
Gerrit-Owner: pespin <pespin(a)sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-Reviewer: osmith <osmith(a)sysmocom.de>
Gerrit-Attention: osmith <osmith(a)sysmocom.de>
Gerrit-Attention: laforge <laforge(a)osmocom.org>
Gerrit-Attention: fixeria <vyanitskiy(a)sysmocom.de>
Gerrit-Comment-Date: Mon, 04 Nov 2024 15:39:26 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: osmith <osmith(a)sysmocom.de>
Comment-In-Reply-To: pespin <pespin(a)sysmocom.de>
osmith has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38621?usp=email )
Change subject: testenv: podman-main: set watchdog timer to 60s
......................................................................
testenv: podman-main: set watchdog timer to 60s
Increase the timer from 10s to 60s, as with 10s I see jobs failing with:
ERROR: /tmp/watchdog was not created, exiting
In theory 10s should already be enough, my guess is that if a jenkins
node is currently under a lot of load then the feed command may take
several seconds and so we hit the previous timer. Even if this is not
the cause, I think it is good to rule it out.
Exiting after 60s if the jenkins job was (manually / with connection
loss) aborted is still relatively quick.
Related: OS#6607
Change-Id: Ide7a9d5bc395106cdaa47cec3aa746a978674c9e
---
M _testenv/data/scripts/testenv-podman-main.sh
1 file changed, 3 insertions(+), 3 deletions(-)
git pull ssh://gerrit.osmocom.org:29418/osmo-ttcn3-hacks refs/changes/21/38621/1
diff --git a/_testenv/data/scripts/testenv-podman-main.sh b/_testenv/data/scripts/testenv-podman-main.sh
index 4b080a6..7f1c16e 100755
--- a/_testenv/data/scripts/testenv-podman-main.sh
+++ b/_testenv/data/scripts/testenv-podman-main.sh
@@ -1,8 +1,8 @@
#!/bin/sh -e
# Simple watchdog script that exits if either:
# * testenv doesn't create /tmp/watchdog every 10s
# * 4 hours have passed
-# This ensures the podman container stops a few seconds after a jenkins job was
+# This ensures the podman container stops a soon after a jenkins job was
# aborted, or if a test is stuck in a loop for hours.
echo "Running testenv-podman-main.sh"
@@ -10,7 +10,7 @@
stop_time=$(($(date +%s) + 3600 * 4))
while [ $(date +%s) -lt $stop_time ]; do
- sleep 10
+ sleep 60
if ! [ -e /tmp/watchdog ]; then
echo "ERROR: /tmp/watchdog was not created, exiting"
@@ -1,8 +1,8 @@
#!/bin/sh -e
# Simple watchdog script that exits if either:
-# * testenv doesn't create /tmp/watchdog every 10s
+# * testenv doesn't create /tmp/watchdog every 60s
# * 4 hours have passed
--
To view, visit https://gerrit.osmocom.org/c/osmo-ttcn3-hacks/+/38621?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: osmo-ttcn3-hacks
Gerrit-Branch: master
Gerrit-Change-Id: Ide7a9d5bc395106cdaa47cec3aa746a978674c9e
Gerrit-Change-Number: 38621
Gerrit-PatchSet: 1
Gerrit-Owner: osmith <osmith(a)sysmocom.de>